==> members-facade-2.0.1-vg-20231023.122701-11-sources.jar: com/bizvane/members/facade/service/inner/MbrIntegralBatchRecordService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.couponfacade.models.vo.SendCouponQuotaBatchRequestVO;
import com.bizvane.members.facade.models.bo.BatchInsertIntegralRecordBO;
import com.bizvane.members.facade.models.bo.BatchTaskBo;
import com.bizvane.members.facade.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

public interface MbrIntegralBatchRecordService {

    //批量插入要调整的积分记录(不处理积分扣减/增加)
    ResponseData<BatchInsertIntegralRecordBO> batchInsertIntegralRecordBeforeProcess(BatchUpdateMemberIntegralVO batchUpdateMemberIntegralVO,SysAccountPO sysAccountPo);

    //
    ResponseData<BatchInsertIntegralRecordBO> batchInsertIntegralRecordFromGiftBagBeforeProcess(BatchUpdateMemberIntegralVO batchUpdateMemberIntegralVO, SendCouponQuotaBatchRequestVO sendCouponQuotaBatchRequestVO);

    //异步处理积分
    void asyncProcessIntegral(BatchInsertIntegralRecordBO batchInsertIntegralRecordBO);



    ResponseData<BatchTaskBo> batchChangeIntegralTask(BatchMemberTaskVo batchMemberTaskVo, SysAccountPO sysAccountPo);


    void asyncBatchChangeIntegralTask(BatchMemberTaskVo batchMemberTaskVo, BatchTaskBo batchTaskBo);


    void asyncRetryChangeIntegralTask(BatchTaskBo batchTaskBo);




    ResponseData<BatchIntegralRecordResponseVO> selectBatchIntegralRecord(BatchIntegralRecordRequestVO batchIntegralRecordRequestVO, Long sysCompanyId, Long brandId);


    ResponseData<String> exportBatchIntegralRecord(BatchIntegralRecordRequestVO batchIntegralRecordRequestVO, SysAccountPO sysAccountPo);

}

==> members-facade-2.0.2-vg-20251031.030103-18-sources.jar: com/bizvane/members/facade/service/inner/MbrIntegralBatchRecordService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.couponfacade.models.vo.SendCouponQuotaBatchRequestVO;
import com.bizvane.members.facade.models.bo.BatchInsertIntegralRecordBO;
import com.bizvane.members.facade.models.bo.BatchTaskBo;
import com.bizvane.members.facade.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

public interface MbrIntegralBatchRecordService {

    //批量插入要调整的积分记录(不处理积分扣减/增加)
    ResponseData<BatchInsertIntegralRecordBO> batchInsertIntegralRecordBeforeProcess(BatchUpdateMemberIntegralVO batchUpdateMemberIntegralVO,SysAccountPO sysAccountPo);

    //
    ResponseData<BatchInsertIntegralRecordBO> batchInsertIntegralRecordFromGiftBagBeforeProcess(BatchChangeIntegralFromGiftBagVO batchChangeIntegralFromGiftBagVO);

    //异步处理积分
    void asyncProcessIntegral(BatchInsertIntegralRecordBO batchInsertIntegralRecordBO);



    ResponseData<BatchTaskBo> batchChangeIntegralTask(BatchMemberTaskVo batchMemberTaskVo, SysAccountPO sysAccountPo);


    void asyncBatchChangeIntegralTask(BatchMemberTaskVo batchMemberTaskVo, BatchTaskBo batchTaskBo);


    void asyncRetryChangeIntegralTask(BatchTaskBo batchTaskBo);




    ResponseData<BatchIntegralRecordResponseVO> selectBatchIntegralRecord(BatchIntegralRecordRequestVO batchIntegralRecordRequestVO, Long sysCompanyId, Long brandId);


    ResponseData<String> exportBatchIntegralRecord(BatchIntegralRecordRequestVO batchIntegralRecordRequestVO, SysAccountPO sysAccountPo);

}
